<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX Network Assistant</source>
        <translation>MX Assistente de Redes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="86"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="109"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="177"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="184"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="219"/>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="225"/>
        <source>IP address</source>
        <translation>Endereço IP</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>Hardware detected</source>
        <translation>Dispositivo detectado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>Enable</source>
        <translation>Activar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="303"/>
        <location filename="../mainwindow.ui" line="593"/>
        <location filename="../mainwindow.ui" line="706"/>
        <source>Re-scan</source>
        <translation>Voltar a procurar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="372"/>
        <source>Enabled</source>
        <translation>Ativado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="377"/>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="382"/>
        <source>Driver</source>
        <translation>Controlador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="387"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="392"/>
        <source>Vendor</source>
        <translation>Fornecedor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="397"/>
        <source>Product</source>
        <translation>Produto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="405"/>
        <source>Disable</source>
        <translation>Desativar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="419"/>
        <source>Active interface</source>
        <translation>Interface activa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="435"/>
        <source>WiFi status</source>
        <translation>Estado do Wi-Fi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="457"/>
        <source>Unblocks all soft/hard blocked wireless devices</source>
        <translation>Desbloqueia todos os dispositivos sem fios (wireless) bloqueados por software ou no equipamento (soft/hard blocked)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="460"/>
        <source>Unblock WiFi Devices</source>
        <translation>Desbloquear Dispositivos Wi-Fi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="492"/>
        <source>Linux drivers</source>
        <translation>Controladores Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="504"/>
        <source>Associated Linux drivers</source>
        <translation>Controladores Linux associados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="513"/>
        <source>Load Driver</source>
        <translation>Carregar controlador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="576"/>
        <source>Unload Driver</source>
        <translation>Descarregar controlador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="613"/>
        <location filename="../mainwindow.cpp" line="833"/>
        <source>Block Driver</source>
        <translation>Bloquear controlador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="632"/>
        <source>Windows drivers</source>
        <translation>Controladores do Windows</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="638"/>
        <source>Available Windows drivers</source>
        <translation>Controladores Windows disponíveis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="672"/>
        <source>Remove Driver</source>
        <translation>Remover controlador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="683"/>
        <source>Add Driver</source>
        <translation>Adicionar controlador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="724"/>
        <source>About NDISwrapper</source>
        <translation>Sobre o NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="736"/>
        <source>Install NDISwrapper</source>
        <translation>Instalar o NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="747"/>
        <source>In order to use Windows drivers you need first to install NDISwrapper</source>
        <translation>Para usar controladores Windows é necessário instalar primeiro o NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="763"/>
        <source>Uninstall NDISwrapper</source>
        <translation>Desinstalar o NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="795"/>
        <source>Net diagnostics</source>
        <translation>Diagnósticos de rede</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="807"/>
        <source>Ping</source>
        <translation>Ping</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="813"/>
        <location filename="../mainwindow.ui" line="933"/>
        <source>Target URL:</source>
        <translation>URL alvo:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="823"/>
        <source>Packets</source>
        <translation>Pacotes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="868"/>
        <location filename="../mainwindow.ui" line="991"/>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="885"/>
        <location filename="../mainwindow.ui" line="1008"/>
        <source>Clear</source>
        <translation>Limpar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="899"/>
        <location filename="../mainwindow.ui" line="1022"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="927"/>
        <source>Traceroute</source>
        <translation>Traceroute</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="943"/>
        <source>Hops</source>
        <translation>Saltos (Hops)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="86"/>
        <source>IP address from router:</source>
        <translation>Endereço IP do encaminhador (router):</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="87"/>
        <source>External IP address:</source>
        <translation>Endereço IP externo:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="124"/>
        <location filename="../mainwindow.cpp" line="137"/>
        <source>Interface: %1</source>
        <translation>Interface: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="124"/>
        <location filename="../mainwindow.cpp" line="138"/>
        <source>Driver: %1</source>
        <translation>Controlador: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="125"/>
        <location filename="../mainwindow.cpp" line="139"/>
        <source>Description: %1</source>
        <translation>Descrição: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <location filename="../mainwindow.cpp" line="140"/>
        <source>Product: %1</source>
        <translation>Produto: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <location filename="../mainwindow.cpp" line="141"/>
        <source>Vendor: %1</source>
        <translation>Fornecedor: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="127"/>
        <location filename="../mainwindow.cpp" line="142"/>
        <source>Enabled: %1</source>
        <translation>Ativado: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="195"/>
        <location filename="../mainwindow.cpp" line="209"/>
        <location filename="../mainwindow.cpp" line="223"/>
        <source>&amp;Copy</source>
        <translation>&amp;Copiar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="197"/>
        <location filename="../mainwindow.cpp" line="211"/>
        <location filename="../mainwindow.cpp" line="225"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="198"/>
        <location filename="../mainwindow.cpp" line="212"/>
        <location filename="../mainwindow.cpp" line="226"/>
        <source>Copy &amp;All</source>
        <translation>Copiar &amp;tudo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="200"/>
        <location filename="../mainwindow.cpp" line="214"/>
        <location filename="../mainwindow.cpp" line="228"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="260"/>
        <location filename="../mainwindow.cpp" line="277"/>
        <source>Traceroute not installed</source>
        <translation>O Traceroute não está instalado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>Traceroute is not installed, do you want to install it now?</source>
        <translation>O Traceroute não está instalado. Instalar agora?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="267"/>
        <source>Traceroute hasn&apos;t been installed</source>
        <translation>O Traceroute não foi instalado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="268"/>
        <source>Traceroute cannot be installed. This may mean you are using the LiveCD or you are unable to reach the software repository,</source>
        <translation>Não é possível instalar o Traceroute. Isto pode resultar de estar a ser usada a instalação externa ou de não estar a ser conseguida ligação ao repositório de software.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>Traceroute is not installed and no Internet connection could be detected so it cannot be installed</source>
        <translation>O Traceroute não está instalado. Não foi detectada nenhuma ligação à Internet, pelo que não é possível proceder à sua instalação</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>No destination host</source>
        <translation>Nenhum hospedeiro (host) como destino</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>Please fill in the destination host field</source>
        <translation>Preencher o campo do hospedeiro de destino</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="445"/>
        <source>Loaded Drivers</source>
        <translation>Controladores carregados</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="454"/>
        <source>Unloaded Drivers</source>
        <translation>Controladores não carregados</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="468"/>
        <source>Blocked Drivers</source>
        <translation>Controladores bloqueados</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="488"/>
        <source>Blocked Broadcom Drivers</source>
        <translation>Controladores Broadcom bloqueados</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="510"/>
        <source>Ndiswrapper is not installed</source>
        <translation>O NDISwrapper não está instalado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="523"/>
        <source>driver installed</source>
        <translation>Controlador instalado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="532"/>
        <source> and in use by </source>
        <translation> e em uso por </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>. Alternate driver: </source>
        <translation>Controlador alternativo: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="603"/>
        <source>Driver removed from blocklist</source>
        <translation>Controlador removido da lista de bloqueados</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="603"/>
        <source>Driver removed from blocklist.</source>
        <translation>Controlador removido da lista de bloqueados.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="609"/>
        <source>Module blocked</source>
        <translation>Módulo bloqueado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="763"/>
        <source>Installation successful</source>
        <translation>Instalação bem sucedida</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="765"/>
        <source>Error detected, could not compile ndiswrapper driver.</source>
        <translation>Detectado um erro; não foi possível compilar o controlador do NDISwrapper.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="768"/>
        <source>Error detected, could not install ndiswrapper.</source>
        <translation>Detectado um erro; não foi possível instalar o NDISwrapper.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="780"/>
        <source>Error encountered while removing Ndiswrapper</source>
        <translation>Detectado um erro ao remover o NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="830"/>
        <source>Unblock Driver</source>
        <translation>Desbloquear controlador</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="862"/>
        <source>enabled</source>
        <translation>activado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="865"/>
        <source>disabled</source>
        <translation>desactivado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="868"/>
        <source>WiFi hardware switch is off</source>
        <translation>O interruptor de Wi-Fi do computador está desligado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="875"/>
        <source>Locate the Windows driver you want to add</source>
        <translation>Localizar o controlador (driver) Windows a adicionar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="876"/>
        <source>Windows installation information file (*.inf)</source>
        <translation>Ficheiro de informação sobre a instalação Windows (*.inf)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="907"/>
        <source>*.sys file not found</source>
        <translation>Não foi encontrado o ficheiro *.sys</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="908"/>
        <source>The *.sys files must be in the same location as the *.inf file. %1 cannot be found</source>
        <translation>Os ficheiros *.sys têm que estar no mesmo local que o ficheiro *.inf. Não foi encontrado o ficheiro %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="919"/>
        <source>sys file reference not found</source>
        <translation>Não foi encontrada a referência do ficheiro sys</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="920"/>
        <source>The sys file for the given driver cannot be determined after parsing the inf file</source>
        <translation>A análise sintáctica (parsing) ao ficheiro inf não permitiu determinar qual é o ficheiro sys para o controlador em questão</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="937"/>
        <source>Ndiswrapper driver removed.</source>
        <translation>O controlador do NDISwrapper foi removido.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="945"/>
        <source>%1 Help</source>
        <translation>Ajuda do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="957"/>
        <source>Could not unlock devices.
WiFi device(s) might already be unlocked.</source>
        <translation>Não foi possível desbloquear os dispositivos.
O(s) dispositivo(s) Wi-Fi podem já estar desbloqueados.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="959"/>
        <source>WiFi devices unlocked.</source>
        <translation>Dispositivos Wi-FI desbloqueados</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="974"/>
        <source>About %1</source>
        <translation>Sobre o %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="975"/>
        <source>Version: </source>
        <translation>Versão: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="976"/>
        <source>Program for troubleshooting and configuring network for MX Linux</source>
        <translation>Programa do MX para resolução de problemas e configuração de rede</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="978"/>
        <source>Copyright (c) MEPIS LLC and MX Linux</source>
        <translation>Direitos de autor (c) MEPIS LLC e MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="979"/>
        <source>%1 License</source>
        <translation>Licença do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1005"/>
        <source>Driver loaded successfully</source>
        <translation>Controlador carregado com êxito</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1020"/>
        <source>Driver unloaded successfully</source>
        <translation>Controlador descarregado com êxito</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="63"/>
        <source>Changelog</source>
        <translation>Registo de alterações</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="76"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <location filename="../main.cpp" line="78"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>O utilizador parece ser o root; para usar este programa, sair e voltar a entrar como utilizador normal.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="79"/>
        <source>You must run this program with admin access.</source>
        <translation>Deve executar este programa como administrador.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="624"/>
        <source>Could not load </source>
        <translation>Não foi possível carregar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="649"/>
        <source>Could not unload </source>
        <translation>Não foi possível descarregar</translation>
    </message>
</context>
</TS>
